package com.yunzhi.nanyang.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.nanyang.common.BaseController;
import com.yunzhi.nanyang.common.ResponseBean;

import java.util.HashMap;
import java.util.List;

import com.yunzhi.nanyang.common.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.yunzhi.nanyang.entity.TaDeviceJob;
import com.yunzhi.nanyang.service.TaDeviceJobService;

/**
 * 设备作业表;(ta_device_job)表控制层
 *
 * @author : http://njyunzhi.com
 * @date : 2022-11-3
 */
@Api(tags = "设备作业表对象功能接口")
@RestController
@RequestMapping("/")
public class TaDeviceJobController extends BaseController {

    @Autowired
    private TaDeviceJobService taDeviceJobService;

//    /**
//     * 通过ID查询单条数据
//     *
//     * @param jobId 主键
//     * @return 实例对象
//     */
//    @ApiOperation("通过ID查询单条数据")
//    @GetMapping("/device-job/{id}")
//    public ResponseBean queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
//        return ResponseBean.success(taDeviceJobService.getById(id));
//    }

    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("设备作业列表")
    @GetMapping("/device-job")
    public ResponseBean list(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                             @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                             @ApiParam("设备分类") @RequestParam(value = "deviceKind", required = false) String deviceKind,
                             @ApiParam("设备编号") @RequestParam(value = "deviceNo", required = false) String deviceNo) throws Exception {

        IPage<TaDeviceJob> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaDeviceJob> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(!StringUtils.isEmpty(deviceKind), "device_kind", deviceKind);
        queryWrapper.like(!StringUtils.isEmpty(deviceNo), "device_no", deviceNo);
        queryWrapper.orderByDesc("job_date");
        IPage<TaDeviceJob> result = taDeviceJobService.page(pg, queryWrapper);

        return ResponseBean.success(result);
    }


    /**
     * 分页查询
     *
     * @param pageNum  当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @ApiOperation("设备作业列表")
    @GetMapping("/device-job/by-org")
    public ResponseBean statis(@ApiParam("页码") @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                               @ApiParam("单页数据量") @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize,
                               @ApiParam("合作社名称") @RequestParam(value = "orgName", required = false) String orgName,
                               @ApiParam("设备分类") @RequestParam(value = "deviceKind", required = false) String deviceKind,
                               @ApiParam("设备编号") @RequestParam(value = "deviceNo", required = false) String deviceNo,
                               @ApiParam(value = "开始时间", example = "2022-10-01") @RequestParam(value = "startDate", required = false) String startDate,
                               @ApiParam(value = "结束时间", example = "2022-10-31") @RequestParam(value = "endDate", required = false) String endDate) throws Exception {

        IPage<TaDeviceJob> pg = new Page<>(pageNum, pageSize);
        IPage<TaDeviceJob> list = taDeviceJobService.statisOrgBy(pg, orgName, deviceKind, deviceNo, startDate, endDate);
        Double totalArea = taDeviceJobService.statisTotalArea(orgName, deviceKind, deviceNo, startDate, endDate);

        return ResponseBean.success(new HashMap<String, Object>(){{
            put("list", list);
            put("totalArea", totalArea);
        }});
    }

//    /**
//     * 新增数据
//     *
//     * @param taDeviceJob 实例对象
//     * @return 实例对象
//     */
//    @ApiOperation("新增数据")
//    @PostMapping("/device-job")
//    public ResponseBean add(@ApiParam("对象实体") @RequestBody TaDeviceJob taDeviceJob) throws Exception {
//        taDeviceJobService.save(taDeviceJob);
//        return ResponseBean.success(taDeviceJob);
//    }
//
//    /**
//     * 更新数据
//     *
//     * @param taDeviceJob 实例对象
//     * @return 实例对象
//     */
//    @ApiOperation("更新数据")
//    @PutMapping("/device-job/{id}")
//    public ResponseBean edit(@ApiParam("对象实体") @RequestBody TaDeviceJob taDeviceJob,
//                             @ApiParam("对象ID") @PathVariable String id) throws Exception {
//        taDeviceJobService.updateById(taDeviceJob);
//        return ResponseBean.success(taDeviceJob);
//    }
//
//    /**
//     * 通过主键删除数据
//     *
//     * @param jobId 主键
//     * @return 是否成功
//     */
//    @ApiOperation("通过主键删除数据")
//    @DeleteMapping("/device-job/{id}")
//    public ResponseBean deleteById(@ApiParam("对象ID") @PathVariable String id) {
//        taDeviceJobService.removeLogicById(id);
//        return ResponseBean.success("success");
//    }
}